RustAnalyzerClient

Struct RustAnalyzerClient 

pub struct RustAnalyzerClient { /* private fields */ }

Implementations

Source

impl RustAnalyzerClient

pub fn new(workspace_root: PathBuf) -> Self

pub async fn start(&mut self) -> Result<()>

pub async fn open_document(&mut self, uri: &str, content: &str) -> Result<()>

pub async fn shutdown(&mut self) -> Result<()>

Shuts rust-analyzer down, attempting the graceful LSP handshake first.

pub async fn force_kill(&mut self)

Kills rust-analyzer immediately, without the LSP shutdown handshake.

Meant for when a graceful Self::shutdown was aborted, so the process must not be left behind.

pub fn is_gone(&self) -> bool

Whether rust-analyzer is gone, i.e. its stdout has closed because it exited or is about to.

pub fn exit_status(&mut self) -> Option<ExitStatus>

The exit status of the rust-analyzer process, if it has exited.

Source

impl RustAnalyzerClient

pub async fn hover( &mut self, uri: &str, line: u32, character: u32, ) -> Result<Value>

pub async fn definition( &mut self, uri: &str, line: u32, character: u32, ) -> Result<Value>

pub async fn references( &mut self, uri: &str, line: u32, character: u32, ) -> Result<Value>

pub async fn completion( &mut self, uri: &str, line: u32, character: u32, ) -> Result<Value>

pub async fn document_symbols(&mut self, uri: &str) -> Result<Value>

pub async fn formatting(&mut self, uri: &str) -> Result<Value>

pub async fn diagnostics(&mut self, uri: &str) -> Result<Value>

pub async fn workspace_diagnostics(&mut self) -> Result<Value>

pub async fn code_actions( &mut self, uri: &str, start_line: u32, start_char: u32, end_line: u32, end_char: u32, ) -> Result<Value>